==> org.eclipse.epsilon.egl.engine_1.3.0.201602270002.jar: src/org/eclipse/epsilon/egl/spec/CodeBackedTemplateSpecification.java <==
/*******************************************************************************
 * Copyright (c) 2011 The University of York.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Louis Rose - initial API and implementation
 ******************************************************************************/
package org.eclipse.epsilon.egl.spec;

import java.net.URI;
import java.util.Collection;

import org.eclipse.epsilon.egl.execute.control.ITemplateExecutionListener;
import org.eclipse.epsilon.egl.formatter.Formatter;
import org.eclipse.epsilon.egl.incremental.IncrementalitySettings;
import org.eclipse.epsilon.egl.internal.IEglModule;
import org.eclipse.epsilon.egl.traceability.Template;


class CodeBackedTemplateSpecification extends EglTemplateSpecification {

	private final String code;
	
	protected CodeBackedTemplateSpecification(String code, Formatter defaultFormatter, IncrementalitySettings incrementalitySettings, Collection<ITemplateExecutionListener> listeners) {
		super("Anonymous", defaultFormatter, incrementalitySettings, listeners);
		
		this.code = code;
	}
	
	public Template createTemplate() {
		return new Template();
	}
	
	public void parseInto(IEglModule module) throws Exception {
		module.parse(code);
	}

	public URI getURI() {
		return null;
	}	
}

==> org.eclipse.epsilon.egl.engine_2.9.0.202512181109.jar: src/org/eclipse/epsilon/egl/spec/CodeBackedTemplateSpecification.java <==
/*******************************************************************************
 * Copyright (c) 2011 The University of York.
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * Contributors:
 *     Louis Rose - initial API and implementation
 ******************************************************************************/
package org.eclipse.epsilon.egl.spec;

import java.net.URI;
import java.util.Collection;

import org.eclipse.epsilon.egl.execute.control.ITemplateExecutionListener;
import org.eclipse.epsilon.egl.formatter.Formatter;
import org.eclipse.epsilon.egl.incremental.IncrementalitySettings;
import org.eclipse.epsilon.egl.internal.IEglModule;
import org.eclipse.epsilon.egl.traceability.Template;
import org.eclipse.epsilon.eol.IImportManager;

class CodeBackedTemplateSpecification extends EglTemplateSpecification {

	private final String code;
	
	protected CodeBackedTemplateSpecification(String code, Formatter defaultFormatter, IncrementalitySettings incrementalitySettings, IImportManager importManager, Collection<ITemplateExecutionListener> listeners) {
		super("Anonymous", defaultFormatter, incrementalitySettings, importManager, listeners);
		
		this.code = code;
	}
	
	@Override
	public Template createTemplate() {
		return new Template();
	}
	
	@Override
	public void parseInto(IEglModule module) throws Exception {
		module.parse(code);
	}

	@Override
	public URI getURI() {
		return null;
	}	
}
